pub trait TypeResourced {
type TypeData;
}Expand description
Represents an association between a resource and its inner data type.
See also: TypeResource and type_resource!.
pub trait TypeResourced {
type TypeData;
}Represents an association between a resource and its inner data type.
See also: TypeResource and type_resource!.